@@ -16,8 +16,8 @@
 
 ;; URL: https://opendylan.org/
 
-;; Package-Version: 0.1.0
-;; Package-Revision: d85409dc3cba
+;; Package-Version: 0.2.0
+;; Package-Revision: c22f339b5394
 ;; Package-Requires: ((emacs "25.1"))
 
 ;;; Commentary:
@@ -63,9 +63,9 @@
   "*Number of additional spaces to indent each continued line.
 
 A continued line may be, for example, a method parameter list
-started on the line following the 'define method', the 2nd and
+started on the line following the `define method', the 2nd and
 subsequent lines of a method call, the 2nd and subsequent lines
-of a module 'use' statement, etc."
+of a module `use' statement, etc."
   :type  'integer
   :group 'dylan)
 
@@ -202,7 +202,7 @@ These must also be simple definitions and are appended to
     "if" "block" "begin" "method" "case" "for" "select" "when" "unless"
     "until" "while"
     ;; Extensions
-    "iterate" "profiling")
+    "collecting" "iterate" "profiling" "dynamic-bind")
   "Words that begin statements with implicit bodies.")
 
 ;; Names beginning "with-", "without-", and "printing-" (for printing-object
@@ -473,6 +473,8 @@ the various keyword list variables."
           ("while[ \t\n]*" "")
           ("iterate[ \t\n]+\\w+[ \t\n]*" "")
           ("profiling[ \t\n]*" "")
+          ("collecting[ \t\n]*" "")
+          ("dynamic-bind[ \t\n]*" "")
           ;; Special patterns for "define method" and "define function", which
           ;; have a return value spec.
           ;; TODO(cgay): comments may appear before/in/after the signature.
@@ -1396,23 +1398,24 @@ LOUDLY is as for `font-lock-fontify-region'."
                 (re-search-forward regexp nil t))
         (match-string-no-properties 1)))))
 
+;;; TODO(cgay): This doesn't verify that the LID file includes the current buffer's file.
+;;; There could be multiple LID files for multile libraries in the same directory.
 (defun dylan-find-buffer-library (path depth)
   "Return the name of the Dylan library the current buffer is in.
-
 Look up libraries in PATH.
-
-DEPTH is the current lookup nesting depth."
+DEPTH is the current lookup nesting depth and should start at 0."
   (let ((lid-files (directory-files path t ".*\\.lid" t)))
     (if lid-files
-      (let ((try-lid (car lid-files)))
-        (with-current-buffer (find-file-noselect try-lid)
-          (goto-char (point-min))
-          (let ((found
-                 (re-search-forward "[Ll]ibrary:[ \t]*\\([^ \n\r\t]+\\)")))
-            (if found
-                (buffer-substring
-                 (match-beginning 1)
-                 (match-end 1))))))
+        (let ((try-lid (car lid-files)))
+          (with-temp-buffer
+            (insert-file-contents try-lid)
+            (goto-char (point-min))
+            (let ((found
+                   (re-search-forward "[Ll]ibrary:[ \t]*\\([^ \n\r\t]+\\)")))
+              (if found
+                  (buffer-substring
+                   (match-beginning 1)
+                   (match-end 1))))))
       (when (< depth 5)
         (dylan-find-buffer-library (concat path "/..") (1+ depth))))))
 
